==> CrystalDiskMark5_1_2Src.zip: CrystalDiskMark/DiskMark.h <==
/*---------------------------------------------------------------------------*/
//       Author : hiyohiyo
//         Mail : hiyohiyo@crystalmark.info
//          Web : http://crystalmark.info/
//      License : The MIT License
//
//                                             Copyright (c) 2007-2015 hiyohiyo
/*---------------------------------------------------------------------------*/

#pragma once

#include "resource.h"


#define THEME_DIR					_T("CdmResource\\theme\\")
#define LANGUAGE_DIR				_T("CdmResource\\language\\")
#define DIALOG_DIR					_T("CdmResource\\dialog\\")

#define MENU_THEME_INDEX			2
#define MENU_LANG_INDEX				4

#ifdef SUISHO_SHIZUKU_SUPPORT
#define MAIN_DIALOG					_T("MainS.html")
#define MAIN_DIALOG_IE8				_T("MainS8.html")
#define ABOUT_DIALOG				_T("AboutS.html")
#define DEFAULT_THEME				THEME_DIR _T("ShizukuTeaBreak\\MainS.css")
#else
#define MAIN_DIALOG					_T("Main.html")
#define MAIN_DIALOG_IE8				_T("Main8.html")
#define ABOUT_DIALOG				_T("About.html")

#define DEFAULT_THEME				THEME_DIR _T("default\\Main.css")
#endif
#define SETTINGS_DIALOG				_T("Settings.html")
#define DEFAULT_LANGUAGE			LANGUAGE_DIR _T("English.lang")

class CDiskMarkApp : public CWinApp
{
public:
	CDiskMarkApp();

	CString m_MainDlgPath;
	CString m_MainDlgPathIE8;
	CString m_AboutDlgPath;
	CString m_SettingsDlgPath;
	CString m_ThemeDir;
	CString m_LangDir;
	DWORD m_ThemeIndex;
	DWORD m_LangIndex;

	CString m_ExeDir;
	CString m_Ini;

public:
	virtual BOOL InitInstance();


	DECLARE_MESSAGE_MAP()
};

extern CDiskMarkApp theApp;

==> CrystalDiskMark5_5_0Src.zip: CrystalDiskMark/DiskMark.h <==
/*---------------------------------------------------------------------------*/
//       Author : hiyohiyo
//         Mail : hiyohiyo@crystalmark.info
//          Web : http://crystalmark.info/
//      License : The MIT License
//
//                                             Copyright (c) 2007-2015 hiyohiyo
/*---------------------------------------------------------------------------*/

#pragma once

#include "resource.h"


#define THEME_DIR					_T("CdmResource\\theme\\")
#define LANGUAGE_DIR				_T("CdmResource\\language\\")
#define DIALOG_DIR					_T("CdmResource\\dialog\\")

#define MENU_THEME_INDEX			2
#define MENU_LANG_INDEX				4

#ifdef SUISHO_SHIZUKU_SUPPORT
#define MAIN_DIALOG					_T("MainS.html")
#define MAIN_DIALOG_IE8				_T("MainS8.html")
#define ABOUT_DIALOG				_T("AboutS.html")
#define DEFAULT_THEME				THEME_DIR _T("ShizukuLiteratureGirl\\MainS.css")
#else
#define MAIN_DIALOG					_T("Main.html")
#define MAIN_DIALOG_IE8				_T("Main8.html")
#define ABOUT_DIALOG				_T("About.html")

#define DEFAULT_THEME				THEME_DIR _T("default\\Main.css")
#endif
#define SETTINGS_DIALOG				_T("Settings.html")
#define DEFAULT_LANGUAGE			LANGUAGE_DIR _T("English.lang")

class CDiskMarkApp : public CWinApp
{
public:
	CDiskMarkApp();

	CString m_MainDlgPath;
	CString m_MainDlgPathIE8;
	CString m_AboutDlgPath;
	CString m_SettingsDlgPath;
	CString m_ThemeDir;
	CString m_LangDir;
	DWORD m_ThemeIndex;
	DWORD m_LangIndex;

	CString m_ExeDir;
	CString m_Ini;

public:
	virtual BOOL InitInstance();


	DECLARE_MESSAGE_MAP()
};

extern CDiskMarkApp theApp;
